@@ -3,23 +3,20 @@ import requests
 from typing import List
 import urllib
 
-from ua_headers import ua
+#from ua_headers import ua
 from .result import Result
 from .error import InvalidCalculation, InvalidPhrase, InvalidLocation
 
 class Google:
 	def __request(query: str, num: str):
-		url = "https://google.com/search?q="+urllib.parse.quote(query)+"&num="+str(num)
-		r = requests.get(url, headers={'User-Agent': ua.linux()})
+		url = "https://google.com/search?q="+urllib.parse.quote(query)+num
+		print(url)
+		r = requests.get(url, headers={'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64)'})
 		return bs(r.text, 'html.parser')
 
 	@classmethod
-	def search(self, query: str, num: str, is_safe: bool = False):
-		if is_safe:
-			safe = "strict"
-		else:
-			safe = "off"
-		req = self.__request(query, "&safe="+safe+"&num="+str(num))
+	def search(self, query: str, num="25"):
+		req = self.__request(query, "&num="+num)
 		res = req.find_all("div", class_="kCrYT")
 		reslist = list()
 		for i in res:
